@@ -1,6 +1,9 @@
-from widgets import FullScreenTextarea
+try:
+    from widgets import FullScreenTextarea
+except ImportError:
+    pass
 
-version = (1, 0, 6)
+version = (1, 0, 7)
 
 
 def get_version():
